@@ -11,7 +11,7 @@ func breakdownCmd(ctx *config.RunContext) *cobra.Command {
 		Use:   "breakdown",
 		Short: "Show full breakdown of costs",
 		Long:  "Show full breakdown of costs",
-		Example: `  Use Terraform directory with any required Terraform flags:
+		Example: `  Use Terraform directory with any required flags:
 
       infracost breakdown --path /path/to/code --terraform-plan-flags "-var-file=my.tfvars"
 
