@@ -7,55 +7,77 @@ import (
 	"os"
 	"runtime/debug"
 
-	"github.com/infracost/infracost/internal/apiclient"
-	"github.com/infracost/infracost/internal/config"
-	"github.com/infracost/infracost/internal/ui"
-	"github.com/infracost/infracost/internal/update"
-	"github.com/infracost/infracost/internal/version"
 	"github.com/pkg/errors"
 	log "github.com/sirupsen/logrus"
 	"github.com/spf13/cobra"
 	"github.com/spf13/pflag"
 
+	"github.com/infracost/infracost/internal/apiclient"
+	"github.com/infracost/infracost/internal/config"
+	"github.com/infracost/infracost/internal/ui"
+	"github.com/infracost/infracost/internal/update"
+	"github.com/infracost/infracost/internal/version"
+
 	"github.com/fatih/color"
 )
 
 func main() {
-	var appErr error
-	updateMessageChan := make(chan *update.Info)
+	Run(nil, nil)
+}
 
+// Run starts the Infracost application with the configured cobra cmds.
+// Cmd args and flags are parsed from the cli, but can also be directly injected
+// using the modifyCtx and args parameters.
+func Run(modifyCtx func(*config.RunContext), args *[]string) {
 	ctx, err := config.NewRunContextFromEnv(context.Background())
 	if err != nil {
 		if err.Error() != "" {
-			ui.PrintError(os.Stderr, err.Error())
+			ui.PrintError(ctx.ErrWriter, err.Error())
 		}
-		os.Exit(1)
+
+		ctx.Exit(1)
 	}
 
+	if modifyCtx != nil {
+		modifyCtx(ctx)
+	}
+
+	var appErr error
+	updateMessageChan := make(chan *update.Info)
+
 	defer func() {
 		if appErr != nil {
-			handleCLIError(ctx, appErr)
+			if v, ok := appErr.(*panicError); ok {
+				handleUnexpectedErr(ctx, v)
+			} else {
+				handleCLIError(ctx, appErr)
+			}
 		}
 
 		unexpectedErr := recover()
 		if unexpectedErr != nil {
-			handleUnexpectedErr(ctx, unexpectedErr)
+			withStack := fmt.Errorf("%s\n%s", unexpectedErr, debug.Stack())
+			handleUnexpectedErr(ctx, withStack)
 		}
 
 		handleUpdateMessage(updateMessageChan)
 
 		if appErr != nil || unexpectedErr != nil {
-			os.Exit(1)
+			ctx.Exit(1)
 		}
 	}()
 
 	startUpdateCheck(ctx, updateMessageChan)
 
-	rootCmd := NewRootCommand(ctx)
+	rootCmd := newRootCmd(ctx)
+	if args != nil {
+		rootCmd.SetArgs(*args)
+	}
+
 	appErr = rootCmd.Execute()
 }
 
-func NewRootCommand(ctx *config.RunContext) *cobra.Command {
+func newRootCmd(ctx *config.RunContext) *cobra.Command {
 	rootCmd := &cobra.Command{
 		Use:     "infracost",
 		Version: version.Version,
@@ -63,12 +85,13 @@ func NewRootCommand(ctx *config.RunContext) *cobra.Command {
 		Long: fmt.Sprintf(`Infracost - cloud cost estimates for Terraform
 
 %s
-  https://infracost.io/docs`, ui.BoldString("DOCS")),
-		Example: `  Generate a cost diff from Terraform directory with any required Terraform flags:
+  Quick start: https://infracost.io/docs
+  Add cost estimates to your pull requests: https://infracost.io/cicd`, ui.BoldString("DOCS")),
+		Example: `  Show cost diff from Terraform directory, using any required flags:
 
       infracost diff --path /path/to/code --terraform-plan-flags "-var-file=my.tfvars"
 
-  Generate a full cost breakdown from Terraform directory with any required Terraform flags:
+  Show full cost breakdown from Terraform directory, using any required flags:
 
       infracost breakdown --path /path/to/code --terraform-plan-flags "-var-file=my.tfvars"`,
 		SilenceErrors: true,
@@ -92,6 +115,7 @@ func NewRootCommand(ctx *config.RunContext) *cobra.Command {
 	rootCmd.AddCommand(diffCmd(ctx))
 	rootCmd.AddCommand(breakdownCmd(ctx))
 	rootCmd.AddCommand(outputCmd(ctx))
+	rootCmd.AddCommand(commentCmd(ctx))
 	rootCmd.AddCommand(completionCmd())
 
 	rootCmd.SetUsageTemplate(fmt.Sprintf(`%s{{if .Runnable}}
@@ -128,7 +152,8 @@ Use "{{.CommandPath}} [command] --help" for more information about a command.{{e
 	))
 
 	rootCmd.SetVersionTemplate("Infracost {{.Version}}\n")
-	rootCmd.SetOut(os.Stdout)
+	rootCmd.SetOut(ctx.OutWriter)
+	rootCmd.SetErr(ctx.ErrWriter)
 
 	return rootCmd
 }
@@ -157,7 +182,7 @@ func checkAPIKey(apiKey string, apiEndpoint string, defaultEndpoint string) erro
 
 func handleCLIError(ctx *config.RunContext, cliErr error) {
 	if cliErr.Error() != "" {
-		ui.PrintError(os.Stderr, cliErr.Error())
+		ui.PrintError(ctx.ErrWriter, cliErr.Error())
 	}
 
 	err := apiclient.ReportCLIError(ctx, cliErr)
@@ -166,12 +191,10 @@ func handleCLIError(ctx *config.RunContext, cliErr error) {
 	}
 }
 
-func handleUnexpectedErr(ctx *config.RunContext, unexpectedErr interface{}) {
-	stack := string(debug.Stack())
+func handleUnexpectedErr(ctx *config.RunContext, err error) {
+	ui.PrintUnexpectedErrorStack(ctx.ErrWriter, err)
 
-	ui.PrintUnexpectedError(unexpectedErr, stack)
-
-	err := apiclient.ReportCLIError(ctx, fmt.Errorf("%s\n%s", unexpectedErr, stack))
+	err = apiclient.ReportCLIError(ctx, err)
 	if err != nil {
 		log.Warnf("Error reporting unexpected error: %s", err)
 	}
@@ -221,12 +244,17 @@ func loadGlobalFlags(ctx *config.RunContext, cmd *cobra.Command) error {
 
 // saveOutFile saves the output of the command to the file path past in the `--out-file` flag
 func saveOutFile(cmd *cobra.Command, outFile string, b []byte) error {
+	return saveOutFileWithMsg(cmd, outFile, fmt.Sprintf("Output saved to %s\n", outFile), b)
+}
+
+// saveOutFile saves the output of the command to the file path past in the `--out-file` flag
+func saveOutFileWithMsg(cmd *cobra.Command, outFile, successMsg string, b []byte) error {
 	err := ioutil.WriteFile(outFile, b, 0644) // nolint:gosec
 	if err != nil {
 		return errors.Wrap(err, "Unable to save output")
 	}
 
-	cmd.PrintErrf("Output saved to %s\n", outFile)
+	cmd.PrintErr(successMsg)
 
 	return nil
 }
