@@ -7,6 +7,7 @@ import (
 	"io"
 	"os"
 	"runtime"
+	"runtime/debug"
 	"sort"
 	"strings"
 	"sync"
@@ -38,6 +39,7 @@ type projectJob = struct {
 
 type projectResult = struct {
 	index    int
+	ctx      *config.ProjectContext
 	projects []*schema.Project
 }
 
@@ -63,6 +65,16 @@ func addRunFlags(cmd *cobra.Command) {
 	_ = cmd.MarkFlagFilename("usage-file", "yml")
 }
 
+// panicError is used to collect goroutine panics into an error interface so
+// that we can do type assertion on err checking.
+type panicError struct {
+	msg string
+}
+
+func (p *panicError) Error() string {
+	return p.msg
+}
+
 func runMain(cmd *cobra.Command, runCtx *config.RunContext) error {
 	if runCtx.Config.IsSelfHosted() && runCtx.Config.EnableDashboard {
 		ui.PrintWarning(cmd.ErrOrStderr(), "The dashboard is part of Infracost's hosted services. Contact hello@infracost.io for help.")
@@ -78,7 +90,6 @@ func runMain(cmd *cobra.Command, runCtx *config.RunContext) error {
 	jobs := make(chan projectJob, numJobs)
 
 	projectResultChan := make(chan projectResult, numJobs)
-	projectContextChan := make(chan *config.ProjectContext, numJobs)
 	errGroup, _ := errgroup.WithContext(context.Background())
 
 	if parallelism > 1 && numJobs > 1 && !runCtx.Config.IsLogging() {
@@ -102,14 +113,22 @@ func runMain(cmd *cobra.Command, runCtx *config.RunContext) error {
 	}
 
 	for i := 0; i < parallelism; i++ {
-		errGroup.Go(func() error {
+		errGroup.Go(func() (err error) {
+			// defer a function to recover from any panics spawned by child goroutines.
+			// This is done as recover works only in the same goroutine that it is called.
+			// We need to catch any child goroutine panics and hand them up to the main caller
+			// so that it can be caught and displayed correctly to the user.
+			defer func() {
+				e := recover()
+				if e != nil {
+					err = &panicError{msg: fmt.Sprintf("%s\n%s", e, debug.Stack())}
+				}
+			}()
 
 			for job := range jobs {
 				mux := pathMuxs[job.projectCfg.Path]
 
 				ctx := config.NewProjectContext(runCtx, job.projectCfg)
-				projectContextChan <- ctx
-
 				configProjects, err := runProjectConfig(cmd, runCtx, ctx, job.projectCfg, mux)
 				if err != nil {
 					return err
@@ -117,6 +136,7 @@ func runMain(cmd *cobra.Command, runCtx *config.RunContext) error {
 
 				projectResultChan <- projectResult{
 					index:    job.index,
+					ctx:      ctx,
 					projects: configProjects,
 				}
 			}
@@ -135,12 +155,6 @@ func runMain(cmd *cobra.Command, runCtx *config.RunContext) error {
 		return err
 	}
 
-	close(projectContextChan)
-	projectContexts := make([]*config.ProjectContext, 0, len(runCtx.Config.Projects))
-	for ctx := range projectContextChan {
-		projectContexts = append(projectContexts, ctx)
-	}
-
 	close(projectResultChan)
 	projectResults := make([]projectResult, 0, len(runCtx.Config.Projects))
 	for result := range projectResultChan {
@@ -151,8 +165,12 @@ func runMain(cmd *cobra.Command, runCtx *config.RunContext) error {
 	})
 
 	projects := make([]*schema.Project, 0)
-	for _, projectResults := range projectResults {
-		projects = append(projects, projectResults.projects...)
+	projectContexts := make([]*config.ProjectContext, 0)
+	for _, projectResult := range projectResults {
+		for _, project := range projectResult.projects {
+			projectContexts = append(projectContexts, projectResult.ctx)
+			projects = append(projects, project)
+		}
 	}
 
 	r, err := output.ToOutputFormat(projects)
@@ -160,6 +178,7 @@ func runMain(cmd *cobra.Command, runCtx *config.RunContext) error {
 		return err
 	}
 
+	r.IsCIRun = runCtx.IsCIRun()
 	r.Currency = runCtx.Config.Currency
 
 	dashboardClient := apiclient.NewDashboardAPIClient(runCtx)
@@ -236,12 +255,7 @@ func runProjectConfig(cmd *cobra.Command, runCtx *config.RunContext, ctx *config
 	provider, err := providers.Detect(ctx)
 	if err != nil {
 		m := fmt.Sprintf("%s\n\n", err)
-		m += fmt.Sprintf("Use the %s flag to specify the path to one of the following:\n", ui.PrimaryString("--path"))
-		m += " - Terraform plan JSON file\n - Terraform/Terragrunt directory\n - Terraform plan file"
-
-		if cmd.Name() != "diff" {
-			m += "\n - Terraform state JSON file"
-		}
+		m += fmt.Sprintf("Try setting --path to a Terraform plan JSON file. See %s for how to generate this.", ui.LinkString("https://infracost.io/troubleshoot"))
 
 		return []*schema.Project{}, clierror.NewSanitizedError(errors.New(m), "Could not detect path type")
 	}
@@ -325,6 +339,7 @@ func runProjectConfig(cmd *cobra.Command, runCtx *config.RunContext, ctx *config
 
 	projects, err := provider.LoadResources(usageData)
 	if err != nil {
+		cmd.PrintErrln()
 		return projects, err
 	}
 
@@ -333,13 +348,13 @@ func runProjectConfig(cmd *cobra.Command, runCtx *config.RunContext, ctx *config
 		NoColor:       runCtx.Config.NoColor,
 		Indent:        "  ",
 	}
-	spinner := ui.NewSpinner("Calculating monthly cost estimate", spinnerOpts)
+	spinner := ui.NewSpinner("Retrieving cloud prices to calculate costs", spinnerOpts)
 	defer spinner.Fail()
 
 	for _, project := range projects {
 		if err := prices.PopulatePrices(runCtx, project); err != nil {
 			spinner.Fail()
-			fmt.Fprintln(os.Stderr, "")
+			cmd.PrintErrln()
 
 			if e := unwrapped(err); errors.Is(e, apiclient.ErrInvalidAPIKey) {
 				return projects, fmt.Errorf("%v\n%s %s %s %s %s\n%s",
@@ -384,7 +399,7 @@ func generateUsageFile(cmd *cobra.Command, runCtx *config.RunContext, projectCtx
 	usageFilePath := projectCfg.UsageFile
 	err := usage.CreateUsageFile(usageFilePath)
 	if err != nil {
-		return errors.Wrap(err, "Error creating  usage file")
+		return errors.Wrap(err, "Error creating usage file")
 	}
 
 	usageFile, err = usage.LoadUsageFile(usageFilePath)
