@@ -12,10 +12,10 @@ import (
 	"github.com/tidwall/gjson"
 )
 
-func PopulatePrices(cfg *config.Config, project *schema.Project) error {
+func PopulatePrices(ctx *config.RunContext, project *schema.Project) error {
 	resources := project.AllResources()
 
-	c := apiclient.NewPricingAPIClient(cfg)
+	c := apiclient.NewPricingAPIClient(ctx)
 
 	err := GetPricesConcurrent(c, resources)
 	if err != nil {
