@@ -6,7 +6,7 @@ import (
 	"github.com/tidwall/gjson"
 )
 
-func GetLambdaFunctionRegistryItem() *schema.RegistryItem {
+func getLambdaFunctionRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
 		Name:  "aws_lambda_function",
 		Notes: []string{"Provisioned concurrency is not yet supported."},
