@@ -3,6 +3,7 @@ package usage
 import (
 	"context"
 	"fmt"
+	"runtime"
 	"sort"
 	"strings"
 
@@ -21,6 +22,14 @@ type ReplaceResourceUsagesOpts struct {
 	OverrideValueType bool
 }
 
+func (s *SyncResult) Merge(other *SyncResult) {
+	s.ResourceCount += other.ResourceCount
+	s.EstimationCount += other.EstimationCount
+	for k, v := range other.EstimationErrors {
+		s.EstimationErrors[k] = v
+	}
+}
+
 func (s *SyncResult) ProjectContext() map[string]interface{} {
 	r := make(map[string]interface{})
 
@@ -60,6 +69,11 @@ func SyncUsageData(usageFile *UsageFile, projects []*schema.Project) (*SyncResul
 	return syncResult, nil
 }
 
+type syncResourceResult struct {
+	ru *ResourceUsage
+	sr *SyncResult
+}
+
 func syncResourceUsages(usageFile *UsageFile, resources []*schema.Resource, referenceFile *ReferenceFile) *SyncResult {
 	syncResult := &SyncResult{
 		EstimationErrors: make(map[string]error),
@@ -75,82 +89,45 @@ func syncResourceUsages(usageFile *UsageFile, resources []*schema.Resource, refe
 	}
 
 	wildCardResources := make(map[string]bool)
-
 	for _, resource := range resources {
+		ru := syncWildCardResource(wildCardResources, resource, referenceFile, existingResourceUsagesMap)
+		if ru != nil {
+			resourceUsages = append(resourceUsages, ru)
+		}
+	}
 
-		// Add existing wildcard resource usages if not already added
-		if strings.HasSuffix(resource.Name, "]") {
-			lastIndexOfOpenBracket := strings.LastIndex(resource.Name, "[")
-			wildCardName := fmt.Sprintf("%s[*]", resource.Name[:lastIndexOfOpenBracket])
+	numWorkers := 4
+	numCPU := runtime.NumCPU()
+	if numCPU*4 > numWorkers {
+		numWorkers = numCPU * 4
+	}
+	if numWorkers > 16 {
+		numWorkers = 16
+	}
+	numJobs := len(resources)
+	jobs := make(chan *schema.Resource, numJobs)
+	results := make(chan syncResourceResult, numJobs)
 
-			if !wildCardResources[wildCardName] {
-				resourceUsage := &ResourceUsage{
-					Name: wildCardName,
-				}
-
-				wildCardResources[wildCardName] = true
-				if existingResourceUsage, ok := existingResourceUsagesMap[wildCardName]; ok {
-					// Merge the usage schema from the reference usage file
-					refResourceUsage := referenceFile.FindMatchingResourceUsage(resource.Name)
-					if refResourceUsage != nil {
-						replaceResourceUsages(resourceUsage, refResourceUsage, ReplaceResourceUsagesOpts{})
-					}
-
-					// Merge the usage schema from the resource struct
-					// We want to override the value type from the usage schema since we can't always tell from the YAML
-					// what the value type should be, e.g. user might add an int value for a float attribute.
-					replaceResourceUsages(resourceUsage, &ResourceUsage{
-						Name:  wildCardName,
-						Items: resource.UsageSchema,
-					}, ReplaceResourceUsagesOpts{OverrideValueType: true})
-
-					replaceResourceUsages(resourceUsage, existingResourceUsage, ReplaceResourceUsagesOpts{})
-					resourceUsages = append(resourceUsages, resourceUsage)
-				}
+	// Fire up the workers
+	for i := 0; i < numWorkers; i++ {
+		go func(jobs <-chan *schema.Resource, results chan<- syncResourceResult) {
+			for r := range jobs {
+				ru, sr := syncResource(r, referenceFile, existingResourceUsagesMap)
+				results <- syncResourceResult{ru, sr}
 			}
-		}
+		}(jobs, results)
+	}
 
-		resourceUsage := &ResourceUsage{
-			Name: resource.Name,
-		}
+	// Feed the workers the jobs of getting prices
+	for _, r := range resources {
+		jobs <- r
+	}
 
-		// Merge the usage schema from the reference usage file
-		refResourceUsage := referenceFile.FindMatchingResourceUsage(resource.Name)
-		if refResourceUsage != nil {
-			replaceResourceUsages(resourceUsage, refResourceUsage, ReplaceResourceUsagesOpts{})
-		}
-
-		// Merge the usage schema from the resource struct
-		// We want to override the value type from the usage schema since we can't always tell from the YAML
-		// what the value type should be, e.g. user might add an int value for a float attribute.
-		replaceResourceUsages(resourceUsage, &ResourceUsage{
-			Name:  resource.Name,
-			Items: resource.UsageSchema,
-		}, ReplaceResourceUsagesOpts{OverrideValueType: true})
-
-		// Merge any existing resource usage
-		existingResourceUsage := existingResourceUsagesMap[resource.Name]
-		if existingResourceUsage != nil {
-			replaceResourceUsages(resourceUsage, existingResourceUsage, ReplaceResourceUsagesOpts{})
-		}
-
-		syncResult.ResourceCount++
-		if resource.EstimateUsage != nil {
-			syncResult.EstimationCount++
-
-			resourceUsageMap := resourceUsage.Map()
-			err := resource.EstimateUsage(context.TODO(), resourceUsageMap)
-			if err != nil {
-				syncResult.EstimationErrors[resource.Name] = err
-				log.Warnf("Error estimating usage for resource %s: %v", resource.Name, err)
-			}
-
-			// Merge in the estimated usage
-			estimatedUsageData := schema.NewUsageData(resource.Name, schema.ParseAttributes(resourceUsageMap))
-			mergeResourceUsageWithUsageData(resourceUsage, estimatedUsageData)
-		}
-
-		resourceUsages = append(resourceUsages, resourceUsage)
+	// Get the result of the jobs
+	for i := 0; i < numJobs; i++ {
+		result := <-results
+		resourceUsages = append(resourceUsages, result.ru)
+		syncResult.Merge(result.sr)
 	}
 
 	sortResourceUsages(resourceUsages, existingOrder)
@@ -160,6 +137,91 @@ func syncResourceUsages(usageFile *UsageFile, resources []*schema.Resource, refe
 	return syncResult
 }
 
+func syncWildCardResource(wildCardResources map[string]bool, resource *schema.Resource, referenceFile *ReferenceFile, existingResourceUsagesMap map[string]*ResourceUsage) *ResourceUsage {
+	var resourceUsage *ResourceUsage
+
+	// Add existing wildcard resource usages if not already added
+	if strings.HasSuffix(resource.Name, "]") {
+		lastIndexOfOpenBracket := strings.LastIndex(resource.Name, "[")
+		wildCardName := fmt.Sprintf("%s[*]", resource.Name[:lastIndexOfOpenBracket])
+
+		if !wildCardResources[wildCardName] {
+			resourceUsage = &ResourceUsage{
+				Name: wildCardName,
+			}
+
+			wildCardResources[wildCardName] = true
+			if existingResourceUsage, ok := existingResourceUsagesMap[wildCardName]; ok {
+				// Merge the usage schema from the reference usage file
+				refResourceUsage := referenceFile.FindMatchingResourceUsage(resource.Name)
+				if refResourceUsage != nil {
+					replaceResourceUsages(resourceUsage, refResourceUsage, ReplaceResourceUsagesOpts{})
+				}
+
+				// Merge the usage schema from the resource struct
+				// We want to override the value type from the usage schema since we can't always tell from the YAML
+				// what the value type should be, e.g. user might add an int value for a float attribute.
+				replaceResourceUsages(resourceUsage, &ResourceUsage{
+					Name:  wildCardName,
+					Items: resource.UsageSchema,
+				}, ReplaceResourceUsagesOpts{OverrideValueType: true})
+
+				replaceResourceUsages(resourceUsage, existingResourceUsage, ReplaceResourceUsagesOpts{})
+			}
+		}
+	}
+
+	return resourceUsage
+}
+
+func syncResource(resource *schema.Resource, referenceFile *ReferenceFile, existingResourceUsagesMap map[string]*ResourceUsage) (*ResourceUsage, *SyncResult) {
+	syncResult := &SyncResult{
+		EstimationErrors: make(map[string]error),
+	}
+
+	resourceUsage := &ResourceUsage{
+		Name: resource.Name,
+	}
+
+	// Merge the usage schema from the reference usage file
+	refResourceUsage := referenceFile.FindMatchingResourceUsage(resource.Name)
+	if refResourceUsage != nil {
+		replaceResourceUsages(resourceUsage, refResourceUsage, ReplaceResourceUsagesOpts{})
+	}
+
+	// Merge the usage schema from the resource struct
+	// We want to override the value type from the usage schema since we can't always tell from the YAML
+	// what the value type should be, e.g. user might add an int value for a float attribute.
+	replaceResourceUsages(resourceUsage, &ResourceUsage{
+		Name:  resource.Name,
+		Items: resource.UsageSchema,
+	}, ReplaceResourceUsagesOpts{OverrideValueType: true})
+
+	// Merge any existing resource usage
+	existingResourceUsage := existingResourceUsagesMap[resource.Name]
+	if existingResourceUsage != nil {
+		replaceResourceUsages(resourceUsage, existingResourceUsage, ReplaceResourceUsagesOpts{})
+	}
+
+	syncResult.ResourceCount++
+	if resource.EstimateUsage != nil {
+		syncResult.EstimationCount++
+
+		resourceUsageMap := resourceUsage.Map()
+		err := resource.EstimateUsage(context.TODO(), resourceUsageMap)
+		if err != nil {
+			syncResult.EstimationErrors[resource.Name] = err
+			log.Warnf("Error estimating usage for resource %s: %v", resource.Name, err)
+		}
+
+		// Merge in the estimated usage
+		estimatedUsageData := schema.NewUsageData(resource.Name, schema.ParseAttributes(resourceUsageMap))
+		mergeResourceUsageWithUsageData(resourceUsage, estimatedUsageData)
+	}
+
+	return resourceUsage, syncResult
+}
+
 // replaceResourceUsages override usageItems from dest with usageItems from src
 func replaceResourceUsages(dest *ResourceUsage, src *ResourceUsage, opts ReplaceResourceUsagesOpts) {
 	if dest == nil || src == nil {
